@@ -15,7 +15,7 @@ extends 'Zing::Watcher';
 
 use Zing::Kernel;
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 # ATTRIBUTES
 
@@ -168,7 +168,7 @@ terminates the process.
 
 =head2 logs
 
-  $ zing logs
+  $ zing logs --level fatal
 
 The C<logs> command taps the centralized log source and outputs new events to
 STDOUT (standard output).
